@@ -214,6 +214,8 @@ def get_definition_without_template_args(data_object):
     For example in 'Result<T> A< B<C> >::f' we want to remove the '< B<C> >' part.
     """
     definition = data_object.definition
+    if (len(data_object.bitfield) > 0):
+        definition += " : " + data_object.bitfield
     qual_name = '::' + data_object.name
     if definition.endswith(qual_name):
         qual_name_start = len(definition) - len(qual_name)
@@ -1085,6 +1087,7 @@ class SphinxRenderer(object):
             else:
                 signature[0] = annotation
 
+        declaration = self.create_template_prefix(node) + declaration
         return self.render_declaration(node, declaration, objtype=obj_type,
                                        update_signature=update_signature)
 
@@ -1108,6 +1111,7 @@ class SphinxRenderer(object):
         if declaration.startswith(enum):
             declaration = declaration[len(enum):]
         declaration += self.make_initializer(node)
+        declaration = self.create_template_prefix(node) + declaration
         return self.render_declaration(node, declaration)
 
     def visit_enumvalue(self, node):
